colour_hdri.process.conversion Module — Colour - HDRI 0.1.0 documentation

# colour_hdri.process.conversion Module

## Conversion Process

Defines the conversion process objects:

- `convert_raw_files_to_dng_files()`
- `convert_dng_files_to_intermediate_files()`

`colour_hdri.process.conversion.` `RAW_CONVERTER` = u'dcraw'

  Command line raw conversion application, usually Dave Coffin’s dcraw.

  RAW_CONVERTER : unicode

`colour_hdri.process.conversion.` `RAW_CONVERSION_ARGUMENTS` = u'-t 0 -D -W -4 -T "{0}"'

  Arguments for the command line raw conversion application for non demosaiced linear tiff file format output.

  RAW_CONVERSION_ARGUMENTS : unicode

`colour_hdri.process.conversion.` `RAW_D_CONVERSION_ARGUMENTS` = u'-t 0 -H 1 -r 1 1 1 1 -4 -q 3 -o 0 -T "{0}"'

  Arguments for the command line raw conversion application for demosaiced linear tiff file format output.

  RAW_D_CONVERSION_ARGUMENTS : unicode

`colour_hdri.process.conversion.` `DNG_CONVERTER` = u'/Applications/Adobe DNG Converter.app/Contents/MacOS/Adobe DNG Converter'

  Command line dng conversion application, usually Adobe DNG Converter.

  DNG_CONVERTER : unicode

`colour_hdri.process.conversion.` `DNG_CONVERSION_ARGUMENTS` = u'-e -d "{0}" "{1}"'

  Arguments for the command line dng conversion application.

  DNG_CONVERSION_ARGUMENTS : unicode

`colour_hdri.process.conversion.` `convert_raw_files_to_dng_files`(raw_files, output_directory)

  Converts given raw files to dng files using given output directory.

  Parameters: | raw_files (array_like) – Raw files to convert to dng files. output_directory (unicode) – Output directory.
  Returns: | dng files.
  Return type: | list

`colour_hdri.process.conversion.` `convert_dng_files_to_intermediate_files`(dng_files, output_directory, demosaicing=False)

  Converts given dng files to intermediate tiff files using given output directory.

  Parameters: | dng_files (array_like) – dng files to convert to intermediate tiff files. output_directory (str) – Output directory. demosaicing (bool) – Perform demosaicing on conversion.
  Returns: | Intermediate tiff files.
  Return type: | list